=====
utils
=====

Check out our full documentation `here <https://dcic-utils.readthedocs.io/en/latest/>`_

This repository contains various utility modules shared amongst several projects in the 4DN-DCIC. It is meant to be used internally by the DCIC team and externally as a Python API to `Fourfront <https://data.4dnucleome.org>`_\ , the 4DN data portal.

pip installable as the ``dcicutils`` package with: ``pip install dcicutils``

See `this document <./docs/getting_started.md>`_ for tips on getting started. `Go here <./docs/examples.md>`_ for examples of some of the most useful functions.


.. image:: https://travis-ci.org/4dn-dcic/utils.svg?branch=master
   :target: https://travis-ci.org/4dn-dcic/utils
   :alt: Build Status


.. image:: https://coveralls.io/repos/github/4dn-dcic/utils/badge.svg?branch=master
   :target: https://coveralls.io/github/4dn-dcic/utils?branch=master
   :alt: Coverage

.. image:: https://readthedocs.org/projects/dcic-utils/badge/?version=latest
   :target: https://dcic-utils.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
